/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the NCD PC-Xview keyboard
 * By Jason Merrill <jason@jarthur.claremont.edu>
 */

static const KeyCode ncdpc_codes [] = {

  /* Row 0 */
  59,
  96, 97, 98, 99,
  100, 101, 102, 103,
  104, 105, 106, 107,
  0, 112, 58,

  /* Row 2 */
  50, 36, 37, 38, 39, 40, 41, 42, 43, 44, 35, 53, 54, 55, 56,
  68, 63, 60,
  111, 95, 91, 93,

  /* Row 3 */
  57, 25, 31, 13, 26, 28, 33, 29, 17, 23, 24, 51, 52, 114,
  69, 62, 61,
  88, 89, 90, 92,

  /* Row 4 */
  121, 9, 27, 12, 14, 15, 16, 18, 19, 20, 48, 49,
  85, 86, 87,

  /* Row 5 */
  118, 34, 32, 11, 30, 10, 22, 21, 45, 46, 47, 117,
  65,
  82, 83, 84, 113,

  /* Row 6 */
  120,
  116, 8, 115,
  119,
  64, 67, 66,
  81, 94
};
